##  APIs
Application programming interfaces (APIs) are software intermediaries that allow two applications to talk to each other. They let your product or service communicate with other products and services without having to know how they’re implemented.
